@@ -31,6 +31,7 @@ import clickreviews.cr_common as cr_common
 TEST_CONTROL = ""
 TEST_MANIFEST = ""
 TEST_PKG_YAML = ""
+TEST_HASHES_YAML = ""
 TEST_README_MD = ""
 TEST_SECURITY = dict()
 TEST_SECURITY_PROFILES = dict()
@@ -74,11 +75,41 @@ def _extract_package_yaml(self):
     return io.StringIO(TEST_PKG_YAML)
 
 
+def _extract_hashes_yaml(self):
+    '''Pretend we read the hashes.yaml file'''
+    return io.StringIO(TEST_HASHES_YAML)
+
+
+def _path_join(self, d, fn):
+    '''Pretend we have a tempdir'''
+    return os.path.join("/fake", fn)
+
+
+def _get_sha512sum(self, fn):
+    '''Pretend we found performed a sha512'''
+    (rc, out) = cr_common.cmd(['sha512sum', os.path.realpath(__file__)])
+    if rc != 0:
+        return None
+    return out.split()[0]
+
+
+def _extract_statinfo(self, fn):
+    '''Pretend we found performed an os.stat()'''
+    return os.stat(os.path.realpath(__file__))
+
+
 def _extract_readme_md(self):
     '''Pretend we read the meta/readme.md file'''
     return TEST_README_MD
 
 
+def _check_innerpath_executable(self, fn):
+    '''Pretend we a file'''
+    if '.nonexec' in fn:
+        return False
+    return True
+
+
 def _extract_click_frameworks(self):
     '''Pretend we enumerated the click frameworks'''
     return ["ubuntu-sdk-13.10",
@@ -239,10 +270,23 @@ patches.append(patch(
 patches.append(patch(
     'clickreviews.cr_common.ClickReview._extract_package_yaml',
     _extract_package_yaml))
+patches.append(patch(
+    'clickreviews.cr_common.ClickReview._extract_hashes_yaml',
+    _extract_hashes_yaml))
+patches.append(patch(
+    'clickreviews.cr_common.ClickReview._path_join',
+    _path_join))
+patches.append(patch(
+    'clickreviews.cr_common.ClickReview._get_sha512sum',
+    _get_sha512sum))
+patches.append(patch(
+    'clickreviews.cr_common.ClickReview._extract_statinfo',
+    _extract_statinfo))
 patches.append(patch(
     'clickreviews.cr_common.ClickReview._extract_click_frameworks',
     _extract_click_frameworks))
 patches.append(patch('clickreviews.cr_common.unpack_click', _mock_func))
+patches.append(patch('clickreviews.cr_common.raw_unpack_pkg', _mock_func))
 patches.append(patch('clickreviews.cr_common.ClickReview._list_all_files',
                _mock_func))
 patches.append(patch(
@@ -261,6 +305,9 @@ patches.append(patch(
 patches.append(patch(
     'clickreviews.cr_lint.ClickReviewLint._extract_readme_md',
     _extract_readme_md))
+patches.append(patch(
+    'clickreviews.cr_lint.ClickReviewLint._check_innerpath_executable',
+    _check_innerpath_executable))
 
 # security overrides
 patches.append(patch(
@@ -400,6 +447,9 @@ class TestClickReview(TestCase):
                                self.test_control['Architecture'])
         self._update_test_pkg_yaml()
 
+        self.test_hashes_yaml = dict()
+        self._update_test_hashes_yaml()
+
         self.test_readme_md = self.test_control['Description']
         self._update_test_readme_md()
 
@@ -514,6 +564,12 @@ class TestClickReview(TestCase):
                                   default_flow_style=False,
                                   indent=4)
 
+    def _update_test_hashes_yaml(self):
+        global TEST_HASHES_YAML
+        TEST_HASHES_YAML = yaml.dump(self.test_hashes_yaml,
+                                     default_flow_style=False,
+                                     indent=4)
+
     def _update_test_readme_md(self):
         global TEST_README_MD
         TEST_README_MD = self.test_readme_md
@@ -736,6 +792,11 @@ class TestClickReview(TestCase):
             self.test_pkg_yaml[key] = value
         self._update_test_pkg_yaml()
 
+    def set_test_hashes_yaml(self, yaml):
+        '''Set hashes.yaml to yaml'''
+        self.test_hashes_yaml = yaml
+        self._update_test_hashes_yaml()
+
     def set_test_readme_md(self, contents):
         '''Set contents of meta/readme.md'''
         if contents is None:
@@ -745,12 +806,57 @@ class TestClickReview(TestCase):
         self._update_test_readme_md()
 
     def set_test_security_manifest(self, app, key, value):
-        '''Set key in security manifest to value. If value is None, remove
-           key'''
+        '''Set key in security manifest and package.yaml to value. If value is
+           None, remove key, if key is None, remove app.
+        '''
+        # package.yaml - we don't know if it is a service or a binary with
+        # these values, so just use 'binaries'
+        if key is None:
+            if 'binaries' in self.test_pkg_yaml:
+                for b in self.test_pkg_yaml['binaries']:
+                    if 'name' in b and b['name'] == app:
+                        self.test_pkg_yaml['binaries'].remove(b)
+                        break
+        elif value is None:
+            if 'binaries' in self.test_pkg_yaml:
+                found = False
+                for b in self.test_pkg_yaml['binaries']:
+                    if 'name' in b and b['name'] == app:
+                        if key in b:
+                            b.remove(key)
+                            found = True
+                            break
+        else:
+            found = False
+            k = key
+            if key == 'template':
+                k = 'security-template'
+            elif key == 'policy_groups':
+                k = 'caps'
+            if 'binaries' in self.test_pkg_yaml:
+                for b in self.test_pkg_yaml['binaries']:
+                    if 'name' in b and b['name'] == app:
+                        # Found the entry, so update key/value
+                        b[k] = value
+                        found = True
+                        break
+            # Did not find the entry, so create one
+            if not found:
+                if 'binaries' not in self.test_pkg_yaml:
+                    self.test_pkg_yaml['binaries'] = []
+                self.test_pkg_yaml['binaries'].append({'name': app,
+                                                       k: value})
+        self._update_test_pkg_yaml()
+
+        # click manifest
         if app not in self.test_security_manifests:
             self.test_security_manifests[app] = dict()
 
-        if value is None:
+        if key is None:
+            if app in self.test_security_manifests:
+                del self.test_security_manifests[app]
+                del self.test_manifest["hooks"][app]
+        elif value is None:
             if key in self.test_security_manifests[app]:
                 self.test_security_manifests[app].pop(key, None)
         else:
@@ -973,8 +1079,8 @@ class TestClickReview(TestCase):
         self._update_test_framework_policy_unknown()
 
     def set_test_systemd(self, app, key, value):
-        '''Set systemd entries. If key is None, snappy-systemd from manifest
-           and yaml.
+        '''Set systemd entries. If key is None, remove snappy-systemd from
+           manifest and yaml.
 
            Note the click manifest and the package.yaml use different
            storage types. pkg_yaml['services'] is a list of dictionaries where
@@ -1041,6 +1147,8 @@ class TestClickReview(TestCase):
         TEST_MANIFEST = ""
         global TEST_PKG_YAML
         TEST_PKG_YAML = ""
+        global TEST_HASHES_YAML
+        TEST_HASHES_YAML = ""
         global TEST_README_MD
         TEST_README_MD = ""
         global TEST_SECURITY
